==> redux-connected-0.0.4.tgz: package/src/sagas/_utils/PostApiActionBuilder.ts <==
import { Action, generateActionsForStore } from 'redux-store-generator';
import { ApiResponse, ApiRequest } from '../../types/types';
import globals from '../../globals';

export class PostApiActionBuilder {
    private apiRequest = {} as ApiRequest;
    private apiResponse = {} as ApiResponse;
    private actions = {} as any;

    constructor() {
        this.actions = generateActionsForStore(globals.structure);
    }

    withRequest(apiRequest: ApiRequest) {
        this.apiRequest = apiRequest;
        return this;
    }

    withResponse(apiResponse: ApiResponse) {
        this.apiResponse = apiResponse;
        return this;
    }

    build(): Action {
        let action = {} as Action;
        const { nodeType, apiVerb, nodeName } = this.apiRequest;
        const { data = {} } = this.apiResponse;
        const actionBag = this.actions[nodeName];

        switch (nodeType + '_' + apiVerb) {
            case 'SINGLE_NODE_get':
                action = actionBag['setAll'](data);
                break;
            case 'QUEUE_NODE_get':
                action = actionBag['pushMany'](data);
                break;
            case 'COLLECTION_NODE_get':
                action = actionBag['setMany']({ items: data });
                break;
            case 'COLLECTION_NODE_add':
                action = actionBag['set'](data.id, data);
                break;
            case 'SINGLE_NODE_patch':
            case 'QUEUE_NODE_push':
            case 'QUEUE_NODE_pop':
            case 'QUEUE_NODE_clear':
            case 'COLLECTION_NODE_patch':
            case 'COLLECTION_NODE_delete':
            default:
                action = actionBag[apiVerb](data);
                break;
        }

        return action;
    }
}

==> redux-connected-0.0.6.tgz: package/src/sagas/_utils/PostApiActionBuilder.ts <==
import { Action, generateActionsForStore } from 'redux-store-generator';
import { ApiResponse, ApiRequest } from '../../types/types';
import globals from '../../globals';

export class PostApiActionBuilder {
    private apiRequest = {} as ApiRequest;
    private apiResponse = {} as ApiResponse;
    private actions = {} as any;

    constructor() {
        this.actions = generateActionsForStore(globals.structure);
    }

    withRequest(apiRequest: ApiRequest) {
        this.apiRequest = apiRequest;
        return this;
    }

    withResponse(apiResponse: ApiResponse) {
        this.apiResponse = apiResponse;
        return this;
    }

    build(): Action {
        let action = {} as Action;
        const { nodeType, apiVerb, nodeName, originalAction } = this.apiRequest;
        const { data = {} } = this.apiResponse;
        const { payload } = originalAction || {};
        const { id } = payload || {};

        const actionBag = this.actions[nodeName];

        switch (nodeType + '_' + apiVerb) {
            case 'SINGLE_NODE_get':
                action = actionBag['setAll'](data);
                break;
            case 'QUEUE_NODE_get':
                action = actionBag['pushMany'](data);
                break;
            case 'COLLECTION_NODE_get':
                action = actionBag['setMany']({ items: data });
                break;
            case 'COLLECTION_NODE_add':
                action = actionBag['set'](data.id, data);
                break;
            case 'COLLECTION_NODE_delete':
                action = actionBag['delete'](id);
                break;
            case 'SINGLE_NODE_patch':
            case 'COLLECTION_NODE_patch':
                action = actionBag['patch'](id, payload);
                break;
            case 'QUEUE_NODE_push':
                action = actionBag['push'](payload);
                break;
            case 'QUEUE_NODE_pop':
            case 'QUEUE_NODE_clear':
            default:
                action = actionBag[apiVerb]();
                break;
        }

        return action;
    }
}
